@@ -247,7 +247,10 @@ unsafe impl RowSetBuffer for TextRowSet {
     unsafe fn bind_to_cursor(&mut self, cursor: &mut impl Cursor) -> Result<(), Error> {
         for (index, column_buffer) in self.buffers.iter_mut().enumerate() {
             let column_number = (index + 1) as u16;
-            cursor.stmt().bind_col(column_number, column_buffer)?;
+            cursor
+                .stmt()
+                .bind_col(column_number, column_buffer)
+                .into_result(cursor.stmt())?;
         }
         Ok(())
     }
@@ -261,7 +264,8 @@ unsafe impl ParameterCollection for &TextRowSet {
     unsafe fn bind_parameters_to(self, stmt: &mut StatementImpl<'_>) -> Result<(), Error> {
         let mut parameter_number = 1;
         for column in &self.buffers {
-            stmt.bind_input_parameter(parameter_number, column)?;
+            stmt.bind_input_parameter(parameter_number, column)
+                .into_result(stmt)?;
             parameter_number += 1;
         }
         Ok(())
